@@ -154,7 +154,8 @@ Capability Limitation: This driver does not return a list of available tables.
 
 =cut
 
-sub dbms_column_types_unsupported { 1 }
+use DBIx::SQLEngine::Driver::Trait::NoColumnTypes ':all';
+
 sub dbms_indexes_unsupported      { 1 }
 sub dbms_storedprocs_unsupported  { 1 }
 
